==> wicket-bootstrap-extensions-2.0.13-sources.jar: de/agilecoders/wicket/extensions/markup/html/bootstrap/references/DatetimePickerJsReference.java <==
package de.agilecoders.wicket.extensions.markup.html.bootstrap.references;

import de.agilecoders.wicket.core.util.Dependencies;
import de.agilecoders.wicket.webjars.request.resource.WebjarsJavaScriptResourceReference;
import org.apache.wicket.Application;
import org.apache.wicket.markup.head.HeaderItem;
import org.apache.wicket.markup.head.JavaScriptHeaderItem;

import java.util.List;

/**
 * Eonasdan datetime-picker js reference
 *
 * @author Alexey Volkov
 * @since 01.02.15
 */
public class DatetimePickerJsReference extends WebjarsJavaScriptResourceReference {

    private static final long serialVersionUID = 1L;

    /**
     * Singleton instance of this reference
     */
    private static final class Holder {

        private static final DatetimePickerJsReference INSTANCE = new DatetimePickerJsReference();
    }

    /**
     * @return the single instance of the resource reference
     */
    public static DatetimePickerJsReference instance() {
        return Holder.INSTANCE;
    }

    /**
     * Private constructor.
     */
    private DatetimePickerJsReference() {
        super("Eonasdan-bootstrap-datetimepicker/current/js/bootstrap-datetimepicker.js");
    }

    @Override
    public List<HeaderItem> getDependencies() {
        return Dependencies.combine(super.getDependencies(),
            JavaScriptHeaderItem.forReference(Application.get().getJavaScriptLibrarySettings().getJQueryReference()),
            MomentWithLocalesJsReference.asHeaderItem());
    }

    /**
     * @return this resource reference singleton instance as header item
     */
    public static HeaderItem asHeaderItem() {
        return JavaScriptHeaderItem.forReference(instance());
    }
}

==> wicket-bootstrap-extensions-7.0.13-sources.jar: de/agilecoders/wicket/extensions/markup/html/bootstrap/references/DatetimePickerJsReference.java <==
package de.agilecoders.wicket.extensions.markup.html.bootstrap.references;

import de.agilecoders.wicket.core.util.Dependencies;
import de.agilecoders.wicket.webjars.request.resource.WebjarsJavaScriptResourceReference;
import org.apache.wicket.Application;
import org.apache.wicket.markup.head.HeaderItem;
import org.apache.wicket.markup.head.JavaScriptHeaderItem;

import java.util.List;

/**
 * Eonasdan datetime-picker js reference
 *
 * @author Alexey Volkov
 * @since 01.02.15
 */
public class DatetimePickerJsReference extends WebjarsJavaScriptResourceReference {

    private static final long serialVersionUID = 1L;

    /**
     * Singleton instance of this reference
     */
    private static final class Holder {

        private static final DatetimePickerJsReference INSTANCE = new DatetimePickerJsReference();
    }

    /**
     * @return the single instance of the resource reference
     */
    public static DatetimePickerJsReference instance() {
        return Holder.INSTANCE;
    }

    /**
     * Private constructor.
     */
    private DatetimePickerJsReference() {
        super("tempusdominus-bootstrap-4/current/js/tempusdominus-bootstrap-4.js");
    }

    @Override
    public List<HeaderItem> getDependencies() {
        return Dependencies.combine(super.getDependencies(),
            JavaScriptHeaderItem.forReference(Application.get().getJavaScriptLibrarySettings().getJQueryReference()),
            MomentWithLocalesJsReference.asHeaderItem());
    }

    /**
     * @return this resource reference singleton instance as header item
     */
    public static HeaderItem asHeaderItem() {
        return JavaScriptHeaderItem.forReference(instance());
    }
}
